vcl 4.1;

backend back {
	.host = "127.0.0.1";
	.port = "80";
}

acl valid_purgers {
	"localhost";
}
sub vcl_recv {

	if (req.url ~ "^/[^?]+\.(jpeg|jpg|xml|png|gif|ico|js|css|txt|gz|zip|lzma|bz2|tgz|tbz|htm|wpl|mp3|wav)(\?.*|)$") {
		set req.url = regsub(req.url, "\?.*$", "");
		unset req.http.cookie;
	}

	

	if (req.method == "PURGE") {
		if (!client.ip ~ valid_purgers) {
			return (synth(405, "Not allowed."));
		}
		return (hash);
	}

	if (req.restarts == 0 && !req.http.x-forwarded-for) {
		set req.http.x-forwarded-for = client.ip;
	}

	set client.identity = client.ip;

	if (req.method != "GET" && req.method != "HEAD") {
		return (pass);
	}

	set req.backend_hint = back;

	if (req.method != "GET" &&
			req.method != "HEAD" &&
			req.method != "PUT" &&
			req.method != "POST" &&
			req.method != "TRACE" &&
			req.method != "OPTIONS" &&
			req.method != "DELETE") {
		return (pipe);
	}

	

	if (req.http.Authorization || req.http.cookie) {
		return (pass);
	}

	return (hash);
}

sub vcl_pipe {
	set bereq.http.X-Forwarded-For = client.ip;

	return (pipe);
}

sub vcl_pass {
	set req.http.X-Forwarded-For = client.ip;

	return (fetch);
}

sub vcl_hit {
	if (req.method == "PURGE") {
		return (synth(200, "Purged."));
	}
}

sub vcl_miss {
	set req.http.X-Forwarded-For = client.ip;

	if (req.method == "PURGE") {
		return (synth(200, "Purged."));
	}

	return (fetch);
}

sub vcl_backend_response {
	set beresp.grace = 60s;
	set beresp.ttl = 60s;

	if (beresp.http.Vary ~ "User-Agent") {
		set beresp.http.Vary = regsub(beresp.http.Vary, ",? *User-Agent *", "");
		set beresp.http.Vary = regsub(beresp.http.Vary, "^, *", "");
		if (beresp.http.Vary == "") {
			unset beresp.http.Vary;
		}
	}

	return (deliver);
}

sub vcl_deliver {
	unset resp.http.X-Varnish;
	unset resp.http.Via;

	if (obj.hits > 0) {
		set resp.http.X-Cache = "h";
	} else {
		set resp.http.X-Cache = "m";
	}
}

sub vcl_backend_error {
	set beresp.http.Content-Type = "text/html; charset=utf-8";
	set beresp.http.Retry-After = "5";
	synthetic({"
		<?xml version="1.0" encoding="utf-8"?>
			<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
			"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
			<html>
			<head>
			<title>"} + beresp.status + " " + beresp.reason + {"</title>
			</head>
			<body>
			<h1>Error "} + beresp.status + " " + beresp.reason + {"</h1>
			<p>"} + beresp.reason + {"</p>
			<h3>Guru Meditation:</h3>
			<p>XID: "} + bereq.xid + {"</p>
			<hr>
			<p>Varnish cache server</p>
			</body>
			</html>
			"});

	return (deliver);
}

sub vcl_synth {
	set resp.http.Content-Type = "text/html; charset=utf-8";
	set resp.http.Retry-After = "5";
	synthetic({"
		<?xml version="1.0" encoding="utf-8"?>
			<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
			"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
			<html>
			<head>
			<title>"} + resp.status + " " + resp.reason + {"</title>
			</head>
			<body>
			<h1>Error "} + resp.status + " " + resp.reason + {"</h1>
			<p>"} + resp.reason + {"</p>
			<h3>Guru Meditation:</h3>
			<p>XID: "} + req.xid + {"</p>
			<hr>
			<p>Varnish cache server</p>
			</body>
			</html>
			"});

	return (deliver);
}
